setwd("/Users/sarahbentley/Dropbox/Publications/Cognition in Context/Psych Sci/DATA/S1")
Lab_CB <- read.csv("Bentley_Cognition in context_Experiment_1_data.csv")


install.packages("ggplot2")
install.packages("multcomp")
install.packages("nlme")
install.packages("ez")
install.packages("reshape2")
install.packages("pastecs")
install.packages("WRS2")
install.packages("plyr")
install.packages("Rmisc")
install.packages("Hmisc")
install.packages("lsmeans")
install.packages("ltm")

library("ggplot2")
library("multcomp")
library("nlme")
library("ez")
library("reshape2")
library("pastecs")
library("WRS2")
library("plyr")
library("Rmisc")
library("Hmisc")
library("car")
library("lme4")
library ("lsmeans")
library ("psych")
library ("ltm")



# Data descriptives -------------------------------------------------------

head(Lab_CB)
colnames(Lab_CB)

describe(Lab_CB$Age)

summary(Lab_CB)
is.factor(Lab_CB$Gender_cat)
Lab_CB$Gender_cat <- as.numeric(Lab_CB$Gender_cat)
table <- table(Lab_CB$Gender_cat)
print(table)
prop.table(table)

# Cronbach’s alpha for Need Satisfaction scale --------------------------------------------------------

# Creating reverse scores
Lab_CB$M_SelfEsteem_meas_R <- (8-Lab_CB$M_SelfEsteem_meas)      
Lab_CB$M_Control_meas_R <- (8-Lab_CB$M_Control_meas)  
Lab_CB$M_Bel_meas_R <- (8-Lab_CB$M_Bel_meas)  
Lab_CB$M_Meaningful_meas_R <- (8-Lab_CB$M_Meaningful_meas)  

# for Need Satisfaction
cronbach.alpha(as.matrix(Lab_CB[,c("M_Bel_meas_R","M_Meaningful_meas_R","M_SelfEsteem_meas","M_Control_meas")]), standardized = TRUE, CI = TRUE, B = 500, na.rm = TRUE)


# Manipulation check ------------------------------------------------------

manip.summ <- summarySE(Lab_CB, measurevar="M_Inclusion_meas", groupvars=c("condition"))
print(manip.summ)

manip_planned <- aov(M_Inclusion_meas~condition, data = Lab_CB)
summary (manip_planned)
summary.lm (manip_planned)

colnames(Lab_CB)
#ezANOVA
ezanova <- ezANOVA(data = Lab_CB,
                   dv = M_Inclusion_meas,
                   wid = Ppt,
                   between = condition,
                   detailed = T)
print(ezanova)

pairwise.t.test(Lab_CB$M_Inclusion_meas, Lab_CB$condition, p.adjust.method = "bonferroni")

describeBy(Lab_CB[,c("SRE","ORE","STR")],list(Lab_CB$condition))
describeBy(Lab_CB[,c("M_Inclusion_meas")],list(Lab_CB$condition))

#Creating barplot to look at recall levels by Need Satisfaction
ggplot(manip.summ, aes(x=condition, y=M_Inclusion_meas)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  theme(axis.title = element_blank())+
  theme(axis.text.y = element_text(size = 20,face = "bold"))+
  theme(axis.text.x = element_text(size = 20,face = "bold"))+
  geom_errorbar(aes(ymin=M_Inclusion_meas-se, ymax=M_Inclusion_meas+se),
                width=.2,                    
                position=position_dodge(.9))

citation("lme4")



# Encoding by condition ------------------------------------------

# Turning the wide format into a long format

Lab_CB.long <- melt(Lab_CB, id.vars = c("Ppt","condition","Maths_tot","Recall", 
                                                        "M_Inclusion_meas","Att_ch","M_ostracism_meas",
                                                        "M_Bel_meas","M_SelfEsteem_meas",
                                                        "M_Meaningful_meas","M_Control_meas",
                                                        "M_selffocus","M_Pr_SF", "M_deep_learn" ,"Age", 
                                                        "Gender_cat" ,"NN",
                                                        "SREpos","OREpos","STRpos",
                                                        "SREneg","OREneg","STRneg",
                                                        "Tot_pos","Tot_neg","Tot_words",
                                        "Tot_yes","Tot_no","Tot_yesSRE","Tot_noSRE",
                                        "SelfPosIndex","OtherNegIndex","SeflNegIndex","OtherPosIndex",
                                        "M_SelfEsteem_meas_R","M_Control_meas_R", 
                                        "M_Bel_meas_R","M_Meaningful_meas_R"), 
                            measured.vars = c("SRE","ORE","STR"),
                            variable.name = "encoding",
                            value.name = "recall")


#Calculating st errors for barplot
Lab_CB.long.summ <- summarySE(Lab_CB.long, measurevar="recall", groupvars=c("condition", "encoding"))


#Creating barplot to look at recall levels by encoding
ggplot(Lab_CB.long.summ, aes(x=encoding, y=recall, fill=condition)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=recall-se, ymax=recall+se),
                width=.2,                    
                position=position_dodge(.9))



#Creating barplot to look at recall levels by condition
ggplot(Lab_CB.long.summ, aes(x=condition, y=recall, fill=encoding)) + 
  theme(axis.title = element_blank())+
  theme(axis.text.y = element_text(size = 20,face = "bold"))+
  theme(axis.text.x = element_text(size = 20,face = "bold"))+
  theme(legend.title = element_text(size = 32 ))+
  theme(legend.text = element_text(size = 26 ))+
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=recall-se, ymax=recall+se),
                width=.2,                    
                position=position_dodge(.9))


# mixed model using lmer

encodingINTX.model <- lmer(recall~condition*encoding+(1|Ppt)+(1|encoding),data = Lab_CB.long,REML = FALSE)
EncodingPlusCondition.model <-lmer(recall~condition+encoding+(1|Ppt)+(1|encoding),data = Lab_CB.long,REML = FALSE)
anova(encodingINTX.model,EncodingPlusCondition.model)
summary(encodingINTX.model)


#planned contrasts:
inclusion <- subset(Lab_CB.long, condition == "inclusion") 
exclusion <- subset(Lab_CB.long, condition == "exclusion")
control <- subset(Lab_CB.long, condition == "control")

inclusionOut <- lme(recall~encoding,
                    random = ~1|Ppt,
                    data = inclusion,
                    method = "ML")
exclusionOut <- lme(recall~encoding,
                    random = ~1|Ppt,
                    data = exclusion,
                    method = "ML")
controlOut <- lme(recall~encoding,
                  random = ~1|Ppt,
                  data = control,
                  method = "ML")

inclusionTukey <- glht(inclusionOut, linfct = mcp(encoding = "Tukey"))
exclusionTukey <- glht(exclusionOut, linfct = mcp(encoding = "Tukey"))
controlTukey <- glht(controlOut, linfct = mcp(encoding = "Tukey"))
summary(inclusionTukey)
summary(exclusionTukey)
summary(controlTukey)

