setwd("/Users/sarahbentley/Dropbox/Publications/Cognition in Context/Psych Sci/DATA/S2")
Lab_TD <- read.csv("Bentley_Cognition in context_Experiment_2_data.csv")


install.packages("ggplot2")
install.packages("multcomp")
install.packages("nlme")
install.packages("ez")
install.packages("reshape2")
install.packages("pastecs")
install.packages("WRS2")
install.packages("plyr")
install.packages("Rmisc")
install.packages("Hmisc")
install.packages("lsmeans")
install.packages("ltm")

library("ggplot2")
library("multcomp")
library("nlme")
library("ez")
library("reshape2")
library("pastecs")
library("WRS2")
library("plyr")
library("Rmisc")
library("Hmisc")
library("car")
library("lme4")
library ("lsmeans")
library ("psych")
library ("ltm")



# Data descriptives -------------------------------------------------------

head(Lab_TD)
colnames(Lab_TD)

describe(Lab_TD$Age)

summary(Lab_TD)
is.factor(Lab_TD$Gender_cat)
Lab_TD$Gender_cat <- as.numeric(Lab_TD$Gender_cat)
table <- table(Lab_TD$Gender_cat)
prop.table(table)


# Cronbach’s alpha for Need Satisfaction scale--------------------------------------------------------

# Creating reverse scores
Lab_TD$Ostracism_1_R <- (8-Lab_TD$Ostracism_1) 
Lab_TD$Ostracism_2_R <- (8-Lab_TD$Ostracism_2)    
Lab_TD$Ostracism_3_R <- (8-Lab_TD$Ostracism_3)    

Lab_TD$Ostracism_8_R <- (8-Lab_TD$Ostracism_8)    
Lab_TD$Ostracism_9_R <- (8-Lab_TD$Ostracism_9)
Lab_TD$Ostracism_10_R <- (8-Lab_TD$Ostracism_10)


# Need Satisfaction scale

cronbach.alpha(as.matrix(Lab_TD[,c("Ostracism_1_R","Ostracism_2_R","Ostracism_3_R","Ostracism_4","Ostracism_5","Ostracism_6",
                                   "Ostracism_8_R","Ostracism_9_R","Ostracism_10_R","Ostracism_11","Ostracism_12","Ostracism_13")]), standardized = TRUE, CI = TRUE, B = 500, na.rm = TRUE)

# Psch inter scale

cronbach.alpha(as.matrix(Lab_TD[,c("PsyIGInter_1","PsyIGInter_2","PsyIGInter_3","PsyIGInter_4")]), standardized = TRUE, CI = TRUE, B = 500, na.rm = TRUE)


# Manipulation check ------------------------------------------------------


#creating the Need Satisfaction scale
Lab_TD$Belonging <- (Lab_TD$Ostracism_1_R+Lab_TD$Ostracism_2_R+Lab_TD$Ostracism_3_R+
                       Lab_TD$Ostracism_4+Lab_TD$Ostracism_5+Lab_TD$Ostracism_6+Lab_TD$Ostracism_8_R+
                       Lab_TD$Ostracism_9_R+Lab_TD$Ostracism_10_R+Lab_TD$Ostracism_11+Lab_TD$Ostracism_12+
                       Lab_TD$Ostracism_13)/12

describeBy(Lab_TD[,c("Belonging")],list(Lab_TD$condition))

Manip.summ <- summarySE(Lab_TD, measurevar="Belonging", groupvars = c("condition"))
print(Manip.summ)

manip_planned <- aov(Belonging~condition, data = Lab_TD)
summary (manip_planned)
summary.lm (manip_planned)

#exANOVA for partial eta squared
colnames(Lab_TD)
ezanova <- ezANOVA(data = Lab_TD,
                   dv = Belonging,
                   wid = Ppt,
                   between = condition,
                   detailed = T)
print(ezanova)

pairwise.t.test(Lab_TD$Belonging, Lab_TD$condition, p.adjust.method = "bonferroni")

describeBy(Lab_TD[,c("SRE","ORE","STR")],list(Lab_TD$condition))
describeBy(Lab_TD[,c("Belonging")],list(Lab_TD$condition))

#Creating barplot to look at recall levels by Need Satisfaction
ggplot(Manip.summ, aes(x=condition, y=Belonging)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  theme(axis.title = element_blank())+
  theme(axis.text.y = element_text(size = 20,face = "bold"))+
  theme(axis.text.x = element_text(size = 20,face = "bold"))+
  geom_errorbar(aes(ymin=Belonging-se, ymax=Belonging+se),
                width=.2,                    
                position=position_dodge(.9))

citation("lme4")

# Encoding by condition ------------------------------------------

# Turning the wide format into a long format

Lab_TD.long <- melt(Lab_TD, id.vars = c("Ppt","condition","Maths_score","M_Ostracism",
                                        "Att.ch","M_UQIGties","M_UQIGcentr","M_UQIGaffect",
                                        "M_UQIGinter","M_UQIGintra","M_MGM","M_DeepLearn",
                                        "M_Accontrol","M_malleability","M_PsyIGties","M_PsyIGcent",
                                        "M_PsyIGaffect","M_PsyInter","M_PsyIntr","M_worksat",
                                        "M_perscon","Att_ch","S_Est_1","M_DASS","M_Lifesat","Age",
                                        "Gender_cat","FirstGen","Naivity","SREpos","SREneg",
                                        "OREpos","OREneg","STRpos","STRneg",
                                        "Tot_pos","Tot_neg","Tot_words", "Tot_yes","Tot_no",
                                        "Tot_yesSRE","Tot_noSRE","SelfPosIndex","SeflNegIndex",
                                        "OtherPosIndex","OtherNegIndex","Ostracism_1", 
                                        "Ostracism_2", "Ostracism_3","Ostracism_4", 
                                        "Ostracism_5", "Ostracism_6", "Ostracism_8",
                                        "Ostracism_9", "Ostracism_10", "Ostracism_11", 
                                        "Ostracism_12", "Ostracism_13","Ostracism_1_R",
                                        "Ostracism_2_R","Ostracism_3_R","Ostracism_8_R",
                                        "Ostracism_9_R","Ostracism_10_R","Belonging","X1stgen",
                                        "no.SREpos","yes.SREpos","no.SREneg","yes.SREneg","no.OREpos",
                                        "yes.OREpos","no.OREneg","yes.OREneg","no.STRpos","yes.STRpos",
                                        "no.STRneg","yes.STRneg","PsyIGInter_1","PsyIGInter_2","PsyIGInter_3","PsyIGInter_4"), 
                    measured.vars = c("SRE","ORE","STR"),
                    variable.name = "encoding",
                    value.name = "recall")

#Calculating st errors for barplot
head(Lab_TD.long)

Lab_TD.long.summ <- summarySE(Lab_TD.long, measurevar="recall", groupvars=c("condition", "encoding"))
print(Lab_TD.long.summ)
#Creating barplot to look at recall levels by encoding
ggplot(Lab_TD.long.summ, aes(x=encoding, y=recall, fill=condition)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=recall-se, ymax=recall+se),
                width=.2,                    
                position=position_dodge(.9))

#Creating barplot to look at recall levels by condition
ggplot(Lab_TD.long.summ, aes(x=condition, y=recall, fill=encoding)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  theme(axis.title = element_blank())+
  theme(axis.text.y = element_text(size = 20,face = "bold"))+
  theme(axis.text.x = element_text(size = 20,face = "bold"))+
  theme(legend.title = element_text(size = 32 ))+
  theme(legend.text = element_text(size = 26 ))+
  geom_errorbar(aes(ymin=recall-se, ymax=recall+se),
                width=.2,                    
                position=position_dodge(.9))


# mixed model using lmer

encodingINTX.model <- lmer(value~condition*variable+(1|Ppt)+(1|variable),data = Lab_TD.long,REML = FALSE)
EncodingPlusCondition.model <- lmer(value~condition+variable+(1|Ppt)+(1|variable),data = Lab_TD.long,REML = FALSE)
anova(encodingINTX.model,EncodingPlusCondition.model)


#planned contrasts:
inclusion <- subset(Lab_TD.long, condition == "Inc") 
exclusion <- subset(Lab_TD.long, condition == "Exc")
control <- subset(Lab_TD.long, condition == "Con")

inclusionOut <- lme(recall~encoding,
                    random = ~1|Ppt,
                    data = inclusion,
                    method = "ML")
exclusionOut <- lme(recall~encoding,
                    random = ~1|Ppt,
                    data = exclusion,
                    method = "ML")
controlOut <- lme(recall~encoding,
                  random = ~1|Ppt,
                  data = control,
                  method = "ML")

inclusionTukey <- glht(inclusionOut, linfct = mcp(encoding = "Tukey"))
exclusionTukey <- glht(exclusionOut, linfct = mcp(encoding = "Tukey"))
controlTukey <- glht(controlOut, linfct = mcp(encoding = "Tukey"))
summary(inclusionTukey)
summary(exclusionTukey)
summary(controlTukey)



# Checking the other variables: ----------------------------------


head(Lab_TD)
colnames(Lab_TD)

summary(lm(M_UQIGties~condition, data = Lab_TD))
summary(lm(M_UQIGcentr~condition, data = Lab_TD))
summary(lm(M_UQIGaffect~condition, data = Lab_TD))
Lab_TD$UQID_mean <- (Lab_TD$M_UQIGties+Lab_TD$M_UQIGcentr+Lab_TD$M_UQIGaffect)/3
describeBy(Lab_TD[,c("UQID_mean")], list(Lab_TD$condition))
summary(lm(UQID_mean~condition, data = Lab_TD))
summary(lm(M_UQIGinter~condition, data = Lab_TD))
summary(lm(M_UQIGintra~condition, data = Lab_TD))

install.packages("varhandle")
library(varhandle)
str(Lab_TD$M_UQIGintra)
str(Lab_TD$M_UQIGinter)
Lab_TD$M_UQIGintra <- unfactor(Lab_TD$M_UQIGintra)

summary(lm(M_PsyIGties~condition, data = Lab_TD))
summary(lm(M_PsyIGcent~condition, data = Lab_TD))
summary(lm(M_PsyIGaffect~condition, data = Lab_TD))
Lab_TD$PsyID_mean <- (Lab_TD$M_PsyIGties+Lab_TD$M_PsyIGcent+Lab_TD$M_PsyIGaffect)/3
summary(lm(PsyID_mean~condition, data = Lab_TD))
summary(lm(M_PsyInter_R~condition, data = Lab_TD))
summary(lm(M_PsyIntr~condition, data = Lab_TD))


# Reversing the measure 
Lab_TD$M_PsyInter_R <- (8-Lab_TD$M_PsyInter)      

summary(lm(M_PsyInter_R~condition, data = Lab_TD))
control_vs_inclusion <- c(1,0,0)
exclusion_vs_inclusion <- c(0,1,0)
contrasts(Lab_TD$condition) <- cbind(control_vs_inclusion,exclusion_vs_inclusion)
str(Lab_TD$condition)
#partial eta using ezANOVA
ezanova <- ezANOVA(data = Lab_TD,
                   dv = M_PsyInter_R,
                   wid = Ppt,
                   between = condition,
                   detailed = T)
print(ezanova)

describeBy(Lab_TD[,c("M_PsyInter_R")], list(Lab_TD$condition))

summary(lm(M_PsyIntr~condition, data = Lab_TD))

colnames(Lab_TD)
cronbach.alpha(as.matrix(Lab_TD[,c("Ostracism_1_R","Ostracism_2_R","Ostracism_3_R","Ostracism_4","Ostracism_5","Ostracism_6",
                                   "Ostracism_8_R","Ostracism_9_R","Ostracism_10_R","Ostracism_11","Ostracism_12","Ostracism_13")]), standardized = TRUE, CI = TRUE, B = 500, na.rm = TRUE)

summary(lm(M_MGM~condition, data = Lab_TD))
summary(lm(M_DeepLearn~condition, data = Lab_TD))
summary(lm(M_Accontrol~condition, data = Lab_TD))
summary(lm(M_malleability~condition, data = Lab_TD))
summary(lm(M_worksat~condition, data = Lab_TD))
summary(lm(M_perscon~condition, data = Lab_TD))
summary(lm(S_Est_1~condition, data = Lab_TD))
summary(lm(M_DASS~condition, data = Lab_TD))
summary(lm(M_Lifesat~condition, data = Lab_TD))
